@@ -13,7 +13,6 @@ from findpapers.models.publication import Publication
 from findpapers.utils.requests_util import DefaultSession
 
 
-DEFAULT_SESSION = DefaultSession()
 DATABASE_LABEL = 'IEEE'
 BASE_URL = 'http://ieeexploreapi.ieee.org'
 MAX_ENTRIES_PER_PAGE = 200
@@ -53,6 +52,24 @@ def _get_search_url(search: Search, api_token: str, start_record: Optional[int]
     if start_record is not None:
         url += f'&start_record={start_record}'
 
+    if search.publication_types is not None:
+
+        content_types = set()
+
+        if 'conference proceedings' in search.publication_types:
+            content_types.add('Conferences')
+        if 'journal' in search.publication_types:
+            content_types.add('Journals')
+        if 'book' in search.publication_types:
+            content_types.add('Books')
+        if 'other' in search.publication_types:
+            content_types.add('Courses')
+            content_types.add('Early Access')
+            content_types.add('Magazines')
+            content_types.add('Standards')
+            
+        url += f'&content_type={",".join(content_types)}'
+
     return url
 
 
@@ -77,7 +94,7 @@ def _get_api_result(search: Search, api_token: str, start_record: Optional[int]
 
     url = _get_search_url(search, api_token, start_record)
 
-    return common_util.try_success(lambda: DEFAULT_SESSION.get(url).json(), 2)
+    return common_util.try_success(lambda: DefaultSession().get(url).json(), 2)
 
 
 def _get_publication(paper_entry: dict) -> Publication:
@@ -87,7 +104,7 @@ def _get_publication(paper_entry: dict) -> Publication:
     Parameters
     ----------
     paper_entry : dict
-        A paper entry retrived from IEEE API
+        A paper entry retrieved from IEEE API
 
     Returns
     -------
@@ -118,7 +135,7 @@ def _get_paper(paper_entry: dict, publication: Publication) -> Paper:
     Parameters
     ----------
     paper_entry : dict
-        A paper entry retrived from IEEE API
+        A paper entry retrieved from IEEE API
     publication : Publication
         A publication instance that will be associated with the paper
 
