@@ -14,7 +14,6 @@ from findpapers.models.publication import Publication
 from findpapers.utils.requests_util import DefaultSession
 
 
-DEFAULT_SESSION = DefaultSession()
 DATABASE_LABEL = 'PubMed'
 BASE_URL = 'https://eutils.ncbi.nlm.nih.gov'
 MAX_ENTRIES_PER_PAGE = 50
@@ -76,7 +75,7 @@ def _get_api_result(search: Search, start_record: Optional[int] = 0) -> dict:  #
 
     url = _get_search_url(search, start_record)
 
-    return common_util.try_success(lambda: xmltodict.parse(DEFAULT_SESSION.get(url).content), 2, pre_delay=1)
+    return common_util.try_success(lambda: xmltodict.parse(DefaultSession().get(url).content), 2, pre_delay=1)
 
 
 def _get_paper_entry(pubmed_id: str) -> dict:  # pragma: no cover
@@ -96,7 +95,7 @@ def _get_paper_entry(pubmed_id: str) -> dict:  # pragma: no cover
 
     url = f'{BASE_URL}/entrez/eutils/efetch.fcgi?db=pubmed&id={pubmed_id}&rettype=abstract'
 
-    return common_util.try_success(lambda: xmltodict.parse(DEFAULT_SESSION.get(url).content), 2, pre_delay=1)
+    return common_util.try_success(lambda: xmltodict.parse(DefaultSession().get(url).content), 2, pre_delay=1)
 
 
 def _get_publication(paper_entry: dict) -> Publication:
@@ -106,7 +105,7 @@ def _get_publication(paper_entry: dict) -> Publication:
     Parameters
     ----------
     paper_entry : dict
-        A paper entry retrived from PubMed API
+        A paper entry retrieved from PubMed API
 
     Returns
     -------
@@ -137,7 +136,7 @@ def _get_paper(paper_entry: dict, publication: Publication) -> Paper:
     Parameters
     ----------
     paper_entry : dict
-        A paper entry retrived from IEEE API
+        A paper entry retrieved from IEEE API
     publication : Publication
         A publication instance that will be associated with the paper
 
@@ -242,10 +241,13 @@ def run(search: Search):
         - The API token cannot be null
     """
 
+    if search.publication_types is not None and 'journal' not in search.publication_types:
+        logging.info('Skiping PubMed search, journal publication type not in filters. Nowadays the PubMed only retrieves papers published on journals.')
+        return
+
     papers_count = 0
     result = _get_api_result(search)
 
-
     if result.get('eSearchResult').get('ErrorList', None) is not None:
         total_papers = 0
     else:
