@@ -12,7 +12,6 @@ from findpapers.models.publication import Publication
 from findpapers.utils.requests_util import DefaultSession
 
 
-DEFAULT_SESSION = DefaultSession()
 DATABASE_LABEL = 'Scopus'
 BASE_URL = 'https://api.elsevier.com'
 
@@ -43,6 +42,23 @@ def _get_query(search: Search) -> str:
     if search.until is not None:
         query += f' AND PUBYEAR < {search.until.year + 1}'
 
+    if search.publication_types is not None:
+
+        publication_types = set()
+
+        if 'conference proceedings' in search.publication_types:
+            publication_types.add('p') # Conference Proceeding
+        if 'journal' in search.publication_types:
+            publication_types.add('j') # Journal
+        if 'book' in search.publication_types:
+            publication_types.add('b') # Book
+            publication_types.add('k') # Book Series
+        if 'other' in search.publication_types:
+            publication_types.add('r') # Report
+            publication_types.add('d') # Trade Publication
+        
+        query += f' AND SRCTYPE({" OR ".join(publication_types)})'
+
     return query
 
 
@@ -65,7 +81,7 @@ def _get_publication_entry(publication_issn: str, api_token: str) -> dict:  # pr
 
     url = f'{BASE_URL}/content/serial/title/issn/{publication_issn}?apiKey={api_token}'
     headers = {'Accept': 'application/json'}
-    response = common_util.try_success(lambda: DEFAULT_SESSION.get(
+    response = common_util.try_success(lambda: DefaultSession().get(
         url, headers=headers).json().get('serial-metadata-response', None), 2)
 
     if response is not None and 'entry' in response and len(response.get('entry')) > 0:
@@ -79,7 +95,7 @@ def _get_publication(paper_entry: dict, api_token: str) -> Publication:
     Parameters
     ----------
     paper_entry : dict
-        A paper entry retrived from scopus API
+        A paper entry retrieved from scopus API
     api_token : str
         A Scopus API token
 
@@ -127,7 +143,7 @@ def _get_paper_page(url: str) -> object:  # pragma: no cover
         A HTML element representing the paper given by the provided URL
     """
 
-    response = common_util.try_success(lambda: DEFAULT_SESSION.get(url), 2)
+    response = common_util.try_success(lambda: DefaultSession().get(url), 2)
     return html.fromstring(response.content)
 
 
@@ -138,7 +154,7 @@ def _get_paper(paper_entry: dict, publication: Publication) -> Paper:
     Parameters
     ----------
     paper_entry : dict
-        A paper entry retrived from scopus API
+        A paper entry retrieved from scopus API
     publication : Publication
         A publication instance that will be associated with the paper
 
@@ -255,7 +271,7 @@ def _get_search_results(search: Search, api_token: str, url: Optional[str] = Non
 
     headers = {'Accept': 'application/json'}
 
-    return common_util.try_success(lambda: DEFAULT_SESSION.get(url, headers=headers).json()['search-results'], 2)
+    return common_util.try_success(lambda: DefaultSession().get(url, headers=headers).json()['search-results'], 2)
 
 
 def enrich_publication_data(search: Search, api_token: str):
